Django Yubico Authentication Backend
====================================

.. image:: https://badge.fury.io/py/django_yubico.png
    :target: https://badge.fury.io/py/django_yubico

.. image:: https://secure.travis-ci.org/Kami/django-yubico-authentication-backend.png?branch=master
        :target: http://travis-ci.org/Kami/django-yubico-authentication-backend

.. image:: https://pypip.in/d/django_yubico/badge.png
        :target: https://crate.io/packages/django_yubico

This backends allows you to add single or a dual factor auth support to your
application via Yubikey.

Documentation
-------------

Documentation is available at https://django-yubico-authentication-backend.readthedocs.org/en/latest/

Supported Django Versions
-------------------------

This module has been tested and it's confirmed to be working with the following Django versions:

* Django 1.0
* Django 1.1
* Django 1.2
* Django 1.3
* Django 1.4
* Django 1.5

License
-------

This module is licensed under the `3-Clause BSD License`_.

.. _`3-Clause BSD License`: http://opensource.org/licenses/BSD-3-Clause
